"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Credential = void 0;
var jsx_runtime_1 = require("react/jsx-runtime");
var react_1 = require("react");
var rimble_ui_1 = require("rimble-ui");
var CredentialComponents_1 = require("./CredentialComponents");
var config_1 = require("../../../config");
var themes_1 = require("../../../themes");
var utils_1 = require("../../../utils");
var elements_1 = require("../../elements");
var useVcSchema_1 = require("../../../services/useVcSchema");
var CredentialHeader_1 = require("./CredentialHeader");
var CredentialProperty_1 = require("./CredentialProperty");
var ViewSchemaButton_1 = require("../Schemas/ViewSchemaButton");
var context_1 = require("../../../context");
var Credential = function (props) {
    var _a;
    var vc = props.vc;
    var vcSchema = useVcSchema_1.useVcSchema(vc).vcSchema;
    var vcType = vc.type[vc.type.length - 1];
    var issuanceDate = typeof vc.issuanceDate === "number"
        ? utils_1.dateTimeFormat(new Date(vc.issuanceDate * 1000))
        : utils_1.dateTimeFormat(new Date(vc.issuanceDate));
    var issuanceDateFormatted = issuanceDate.dateFormatted + " at " + issuanceDate.timeFormatted;
    var expirationDate = vc.expirationDate && utils_1.dateTimeFormat(new Date(vc.expirationDate));
    var expirationDateFormatted = expirationDate && expirationDate.dateFormatted + " at " + expirationDate.timeFormatted;
    var expired = vc.expirationDate && new Date(vc.expirationDate) < new Date(Date.now());
    var issuer = typeof vc.issuer === "string" ? vc.issuer : vc.issuer.id;
    var vcUrl = ((_a = vc.proof) === null || _a === void 0 ? void 0 : _a.jwt) && config_1.config.SEARCH_UI_URL + "/vc-validator?vc=" + vc.proof.jwt;
    var _b = react_1.useState(props.isOpen || false), isOpen = _b[0], setIsOpen = _b[1];
    return (jsx_runtime_1.jsxs(rimble_ui_1.Box, __assign({ bg: themes_1.baseColors.white, border: 2, borderRadius: 2, boxShadow: 1, maxWidth: "480px", mb: 3, overflow: "hidden", width: "100%" }, { children: [jsx_runtime_1.jsx(CredentialHeader_1.CredentialHeader, { issuer: issuer, vc: vc, vcType: vcType, vcSchema: vcSchema }, void 0),
            isOpen && (jsx_runtime_1.jsxs(jsx_runtime_1.Fragment, { children: [jsx_runtime_1.jsx(rimble_ui_1.Box, __assign({ borderBottom: 2, mb: 3, pb: 1, pt: 2, px: 3 }, { children: jsx_runtime_1.jsx(rimble_ui_1.Table, __assign({ border: 0, boxShadow: 0, mb: 2, width: "100%", style: { tableLayout: "fixed" } }, { children: jsx_runtime_1.jsx("tbody", { children: Object.entries(vc.credentialSubject).map(function (_a) {
                                    var _b, _c, _d;
                                    var key = _a[0], value = _a[1];
                                    // "type" is a reserved keyword in JSON-LD, and `credentialSubject.type` is just used to define what semantic type of linked data the VC subject is, and we present that info elsewhere as the schema, so would be redundant to list it. Some issuers include `credentialSubject.type` in every single VC.
                                    return key !== "type" && (jsx_runtime_1.jsx(CredentialProperty_1.CredentialProperty, { keyName: key, value: value, schema: (_d = (_c = (_b = vcSchema === null || vcSchema === void 0 ? void 0 : vcSchema.parsedJsonSchema.properties) === null || _b === void 0 ? void 0 : _b.credentialSubject) === null || _c === void 0 ? void 0 : _c.properties) === null || _d === void 0 ? void 0 : _d[key] }, key));
                                }) }, void 0) }), void 0) }), void 0),
                    jsx_runtime_1.jsx(rimble_ui_1.Box, __assign({ mb: 3, px: 3 }, { children: jsx_runtime_1.jsx(rimble_ui_1.Table, __assign({ border: 0, boxShadow: 0, mb: 3, width: "100%", style: { tableLayout: "fixed" } }, { children: jsx_runtime_1.jsxs("tbody", { children: [vc.credentialSubject.id && (jsx_runtime_1.jsxs(CredentialComponents_1.CredentialTR, { children: [jsx_runtime_1.jsx(CredentialComponents_1.CredentialDetailsTDLeft, { children: "Subject" }, void 0),
                                            jsx_runtime_1.jsx(CredentialComponents_1.CredentialDetailsTDRight, { children: jsx_runtime_1.jsxs(rimble_ui_1.Flex, __assign({ alignItem: "center", justifyContent: "flex-end" }, { children: [utils_1.truncateDid(vc.credentialSubject.id), jsx_runtime_1.jsx(rimble_ui_1.Box, __assign({ ml: 1 }, { children: jsx_runtime_1.jsx(elements_1.CopyToClipboard, { text: vc.credentialSubject.id, size: "16px" }, void 0) }), void 0)] }), void 0) }, void 0)] }, void 0)),
                                    jsx_runtime_1.jsxs(CredentialComponents_1.CredentialTR, { children: [jsx_runtime_1.jsx(CredentialComponents_1.CredentialDetailsTDLeft, { children: "Issuer" }, void 0),
                                            jsx_runtime_1.jsx(CredentialComponents_1.CredentialDetailsTDRight, { children: jsx_runtime_1.jsxs(rimble_ui_1.Flex, __assign({ alignItem: "center", justifyContent: "flex-end" }, { children: [utils_1.truncateDid(issuer), jsx_runtime_1.jsx(rimble_ui_1.Box, __assign({ ml: 1 }, { children: jsx_runtime_1.jsx(elements_1.CopyToClipboard, { text: issuer, size: "16px" }, void 0) }), void 0)] }), void 0) }, void 0)] }, void 0),
                                    jsx_runtime_1.jsxs(CredentialComponents_1.CredentialTR, { children: [jsx_runtime_1.jsx(CredentialComponents_1.CredentialDetailsTDLeft, { children: "Date Issued" }, void 0),
                                            jsx_runtime_1.jsx(CredentialComponents_1.CredentialDetailsTDRight, { children: issuanceDateFormatted }, void 0)] }, void 0),
                                    expirationDate && (jsx_runtime_1.jsxs(CredentialComponents_1.CredentialTR, { children: [jsx_runtime_1.jsx(CredentialComponents_1.CredentialDetailsTDLeft, __assign({ color: expired ? themes_1.colors.danger.base : themes_1.colors.silver }, { children: "Expires" }), void 0),
                                            jsx_runtime_1.jsx(CredentialComponents_1.CredentialDetailsTDRight, { children: expirationDateFormatted }, void 0)] }, void 0))] }, void 0) }), void 0) }), void 0),
                    (vcSchema === null || vcSchema === void 0 ? void 0 : vcSchema.slug) && (jsx_runtime_1.jsx(rimble_ui_1.Box, __assign({ borderTop: 2, mb: 3, px: 3, pt: 3 }, { children: jsx_runtime_1.jsx(rimble_ui_1.Table, __assign({ border: 0, boxShadow: 0, mb: 3, width: "100%", style: { tableLayout: "fixed" } }, { children: jsx_runtime_1.jsx("tbody", { children: jsx_runtime_1.jsxs(CredentialComponents_1.CredentialTR, { children: [jsx_runtime_1.jsx(CredentialComponents_1.CredentialDetailsTDLeft, { children: "Schema" }, void 0),
                                        jsx_runtime_1.jsx(CredentialComponents_1.CredentialDetailsTDRight, { children: jsx_runtime_1.jsx(ViewSchemaButton_1.ViewSchemaButton, __assign({ schema: vcSchema }, { children: jsx_runtime_1.jsx("u", { children: vcSchema.slug }, void 0) }), void 0) }, void 0)] }, void 0) }, void 0) }), void 0) }), void 0)),
                    vcUrl && props.renderContext !== context_1.RENDER_CONTEXT.SEARCH && (jsx_runtime_1.jsx(rimble_ui_1.Box, __assign({ my: 4, px: 3 }, { children: jsx_runtime_1.jsx(rimble_ui_1.Button.Outline, __assign({ as: "a", href: vcUrl, size: "small", target: "_blank", width: "100%" }, { children: "Verify on Serto Search" }), void 0) }), void 0))] }, void 0)),
            jsx_runtime_1.jsx(rimble_ui_1.Box, __assign({ pb: 1, px: 2, pt: 2 }, { children: jsx_runtime_1.jsx(CredentialComponents_1.CredentialFooter, { expired: expired, isOpen: isOpen, renderContext: props.renderContext, setIsOpen: function (isOpen) { return setIsOpen(isOpen); }, vc: vc, vcUrl: vcUrl }, void 0) }), void 0)] }), void 0));
};
exports.Credential = Credential;
//# sourceMappingURL=Credential.js.map