import { DefaultSchemaMetadata, JsonSchema, JsonSchemaNode } from "vc-schema-tools";
/** Metadata fields specific to our use-case, intended to be stored in the `$metadata` object in a JSON Schema. */
export interface SchemaMetadata extends DefaultSchemaMetadata {
    version: string;
    slug: string;
    icon?: string;
    discoverable?: boolean;
}
/** In-progress schema interface during CreateSchema flow. */
export declare type WorkingSchema = Partial<JsonSchema<Partial<SchemaMetadata>>>;
export declare type CompletedSchema = JsonSchema<SchemaMetadata>;
/** Data format expected by API. */
export interface SchemaDataInput extends SchemaMetadata {
    name: string;
    description?: string;
    jsonSchema: string;
    ldContext: string;
    /** DEPRECATED */
    ldContextPlus?: string;
}
/** Data format returned by API. */
export interface SchemaDataResponse extends SchemaDataInput {
    id: string;
    created: string;
    updated: string;
    tenant: any;
    deleted?: string;
    favorite?: boolean;
    favoriteCount?: number;
    creator?: {
        name: string;
        /** username */
        nickName: string;
        picture: string;
        /** JWT subject */
        identifier: string;
    };
    ipfsHash?: {
        jsonSchema?: string;
        ldContext?: string;
    };
}
export declare const defaultSchemaProperties: {
    $linkedData: {
        term: string;
        "@id": string;
    };
    title: string;
    type: string;
    format: string;
}[];
export declare const defaultSchemaPropertiesRequired: boolean[];
export declare const newSchemaAttribute: JsonSchemaNode;
export declare const baseWorkingSchema: WorkingSchema;
