"use strict";
/* eslint-disable @typescript-eslint/no-non-null-assertion */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSchemaUris = exports.getLdTypesFromSchemaResponse = exports.schemaResponseToWorkingSchema = exports.jsonSchemaToSchemaInput = exports.ensureFullSchema = exports.isFullSchema = exports.typeOptions = exports.NESTED_TYPE_KEY = void 0;
var slugify_1 = __importDefault(require("@sindresorhus/slugify"));
var vc_schema_tools_1 = require("vc-schema-tools");
var types_1 = require("./types");
exports.NESTED_TYPE_KEY = "NESTED";
exports.typeOptions = __assign({}, vc_schema_tools_1.jsonLdSchemaTypeMap);
exports.typeOptions[exports.NESTED_TYPE_KEY] = {
    type: "object",
    required: [],
    properties: {
        "": __assign({}, types_1.newSchemaAttribute),
    },
};
function isFullSchema(schema) {
    var _a;
    return !!(schema.$metadata && ((_a = schema.properties) === null || _a === void 0 ? void 0 : _a.credentialSubject));
}
exports.isFullSchema = isFullSchema;
/** Some imported/pasted schemas (like traceability ones) may only represent `credentialSubject`. This function creates a full JSON Schema document for VC from that: adding required VC properties, nesting schema properties under `credentialSubject`, adding metadata, $id, etc. */
function ensureFullSchema(_schema, buildSchemaUrl) {
    var _a, _b, _c;
    if (_schema.$metadata && ((_a = _schema.properties) === null || _a === void 0 ? void 0 : _a.credentialSubject)) {
        return _schema;
    }
    var schema = vc_schema_tools_1.generateLinkedData(_schema);
    var name = schema.title || "";
    var slug = ((_b = schema.$metadata) === null || _b === void 0 ? void 0 : _b.slug) || slugify_1.default(name);
    var version = ((_c = schema.$metadata) === null || _c === void 0 ? void 0 : _c.version) || "1.0";
    var jsonSchemaUrl = buildSchemaUrl(slug, "json-schema", version);
    var jsonLdContextUrl = buildSchemaUrl(slug, "ld-context", version);
    var _d = vc_schema_tools_1.generateSchemaLdTypes(schema), subjectLdType = _d.subjectLdType, credLdType = _d.credLdType;
    return __assign(__assign({ $schema: "http://json-schema.org/draft-07/schema#", $id: jsonSchemaUrl, $linkedData: { term: credLdType, "@id": credLdType }, $metadata: __assign({ slug: slug,
            version: version, uris: {
                jsonLdContext: jsonLdContextUrl,
                jsonSchema: jsonSchemaUrl,
            } }, schema.$metadata), title: name, description: schema.description }, vc_schema_tools_1.baseVcJsonSchema), { properties: __assign(__assign({}, vc_schema_tools_1.baseVcJsonSchema.properties), { credentialSubject: {
                $linkedData: { term: subjectLdType, "@id": subjectLdType },
                type: "object",
                required: schema.required || [],
                properties: schema.properties,
            } }) });
}
exports.ensureFullSchema = ensureFullSchema;
/** Take a JSON Schema source, fill in any missing pieces, and wrap it in the metadata expected in the SchemaDataInput type. */
function jsonSchemaToSchemaInput(schema, buildSchemaUrl) {
    var _a, _b, _c, _d, _e, _f;
    var schemaData = __assign(__assign({}, schema), { $metadata: __assign({ slug: slugify_1.default(schema.title || ""), uris: {} }, schema.$metadata) });
    var metadata = schema.$metadata || {};
    var jsonSchemaUrl = (_a = metadata.uris) === null || _a === void 0 ? void 0 : _a.jsonSchema;
    var jsonLdContextUrl = (_b = metadata.uris) === null || _b === void 0 ? void 0 : _b.jsonLdContext;
    if (buildSchemaUrl) {
        jsonSchemaUrl = jsonSchemaUrl || buildSchemaUrl(metadata.slug || "", "json-schema", metadata.version);
        jsonLdContextUrl = jsonLdContextUrl || buildSchemaUrl(metadata.slug || "", "ld-context", metadata.version);
    }
    if (jsonSchemaUrl) {
        schemaData.$id = schemaData.$id || jsonSchemaUrl;
        if (!((_d = (_c = schemaData.$metadata) === null || _c === void 0 ? void 0 : _c.uris) === null || _d === void 0 ? void 0 : _d.jsonSchema)) {
            schemaData.$metadata.uris.jsonSchema = jsonSchemaUrl;
        }
    }
    if (jsonLdContextUrl) {
        if (!((_f = (_e = schemaData.$metadata) === null || _e === void 0 ? void 0 : _e.uris) === null || _f === void 0 ? void 0 : _f.jsonLdContext)) {
            schemaData.$metadata.uris.jsonLdContext = jsonLdContextUrl;
        }
    }
    var schemaInstance = new vc_schema_tools_1.VcSchema(schemaData);
    return __assign(__assign({}, schemaData.$metadata), { name: schema.title || "", description: schema.description, ldContext: schemaInstance.getJsonLdContextString(), jsonSchema: schemaInstance.getJsonSchemaString(), 
        // @TODO/tobek Deprecated and unused, but needed until API is updated to not require it
        ldContextPlus: "" });
}
exports.jsonSchemaToSchemaInput = jsonSchemaToSchemaInput;
/** Used e.g. for taking an existing schema response from DB and using it to populate the schema creator/editor when editing a schema. */
function schemaResponseToWorkingSchema(schemaResponse) {
    var _a, _b;
    var jsonSchema = JSON.parse(schemaResponse.jsonSchema);
    if (!schemaResponse.ldContextPlus) {
        // new version, everything is in JSON Schema
        return jsonSchema;
    }
    // old version, grab metadata from old LD Context Plus:
    var ldContextPlus = JSON.parse(schemaResponse.ldContextPlus);
    jsonSchema.$metadata = ldContextPlus["@context"]["@metadata"];
    delete jsonSchema.$metadata.uris.jsonLdContextPlus;
    var _c = getLdTypesFromSchemaResponse(schemaResponse), subjectLdType = _c.subjectLdType, credLdType = _c.credLdType;
    jsonSchema.$linkedData = { term: credLdType, "@id": credLdType };
    if ((_a = jsonSchema.properties) === null || _a === void 0 ? void 0 : _a.credentialSubject) {
        jsonSchema.properties.credentialSubject = vc_schema_tools_1.generateLinkedData((_b = jsonSchema.properties) === null || _b === void 0 ? void 0 : _b.credentialSubject);
        jsonSchema.properties.credentialSubject.$linkedData = {
            term: subjectLdType,
            "@id": subjectLdType,
        };
    }
    return jsonSchema;
}
exports.schemaResponseToWorkingSchema = schemaResponseToWorkingSchema;
function getLdTypesFromSchemaResponse(schemaResponse) {
    var _a, _b, _c, _d;
    var jsonSchema = JSON.parse(schemaResponse.jsonSchema);
    var subjectLdType = (_c = (_b = (_a = jsonSchema.properties) === null || _a === void 0 ? void 0 : _a.credentialSubject) === null || _b === void 0 ? void 0 : _b.$linkedData) === null || _c === void 0 ? void 0 : _c.term;
    var credLdType = (_d = jsonSchema.$linkedData) === null || _d === void 0 ? void 0 : _d.term;
    if (!credLdType && schemaResponse.ldContextPlus) {
        // old schema, we can get the type this way:
        credLdType = JSON.parse(schemaResponse.ldContextPlus)["@context"]["@rootType"];
    }
    if (!credLdType) {
        console.error("Invalid schema: Could not obtain LD types for schema", schemaResponse);
        throw Error("Invalid schema: Could not obtain LD types for schema");
    }
    return { subjectLdType: subjectLdType, credLdType: credLdType };
}
exports.getLdTypesFromSchemaResponse = getLdTypesFromSchemaResponse;
function getSchemaUris(schema) {
    var _a, _b, _c, _d;
    if (((_a = schema.ipfsHash) === null || _a === void 0 ? void 0 : _a.jsonSchema) && ((_b = schema.ipfsHash) === null || _b === void 0 ? void 0 : _b.ldContext)) {
        return {
            jsonSchema: "https://ipfs.infura.io/ipfs/" + schema.ipfsHash.jsonSchema,
            jsonLdContext: "https://ipfs.infura.io/ipfs/" + schema.ipfsHash.ldContext,
        };
    }
    return schema.uris || ((_d = (_c = JSON.parse(schema.jsonSchema)) === null || _c === void 0 ? void 0 : _c.$metadata) === null || _d === void 0 ? void 0 : _d.uris);
}
exports.getSchemaUris = getSchemaUris;
//# sourceMappingURL=utils.js.map