"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useVcSchema = void 0;
var react_1 = require("react");
var swr_1 = __importDefault(require("swr"));
var SertoUiContext_1 = require("../context/SertoUiContext");
/** To improve lookup times and save computation on parsing JSON */
var schemaCache = {};
/**
 * Given a VC, returns the Serto Schemas representation of its schema.
 *
 * This should probably be implemented with some API that finds schema by VC, but for now we can do it just by just getting all schemas (getSchemas request is probably cached anyway) and searching through it for the right schema.
 *
 * @NOTE This only handles VCs issued using Serto Schemas schemas. Some of this functionality could be implemented by fetching @context and/or JSON Schema from the URLs in the VC and transforming those.
 */
function useVcSchema(vc) {
    var schemasService = react_1.useContext(SertoUiContext_1.SertoUiContext).schemasService;
    var _a = swr_1.default("getSchemas", function () { return schemasService.getSchemas(); }, {
        revalidateOnFocus: false,
    }), data = _a.data, error = _a.error, loading = _a.isValidating;
    var vcSchema = react_1.useMemo(function () {
        var _a, _b;
        var contextUrls = typeof vc["@context"] === "string" ? [vc["@context"]] : vc["@context"];
        var types = typeof vc.type === "string" ? [vc.type] : vc.type;
        if (!data || !(contextUrls === null || contextUrls === void 0 ? void 0 : contextUrls.length) || !(types === null || types === void 0 ? void 0 : types.length)) {
            return;
        }
        var cachedSchema = (_a = schemaCache[contextUrls[contextUrls.length - 1]]) === null || _a === void 0 ? void 0 : _a[types[types.length - 1]];
        if (cachedSchema) {
            return cachedSchema;
        }
        for (var i = 0; i < data.length; ++i) {
            var jsonSchema = void 0;
            var ldTerm = void 0;
            for (var j = 0; j < contextUrls.length; ++j) {
                if (data[i].jsonSchema.includes("\"jsonLdContext\":\"" + contextUrls[j] + "\"")) {
                    try {
                        jsonSchema = jsonSchema || JSON.parse(data[i].jsonSchema);
                        ldTerm = ldTerm || ((_b = jsonSchema === null || jsonSchema === void 0 ? void 0 : jsonSchema.$linkedData) === null || _b === void 0 ? void 0 : _b.term);
                        for (var k = 0; k < types.length; ++k) {
                            if (types[k] === ldTerm && jsonSchema) {
                                var parsedSchema = __assign(__assign({}, data[i]), { parsedJsonSchema: jsonSchema });
                                schemaCache[contextUrls[j]] = schemaCache[contextUrls[j]] || {};
                                schemaCache[contextUrls[j]][types[k]] = parsedSchema;
                                return parsedSchema;
                            }
                        }
                    }
                    catch (err) {
                        console.error("Failed to parse JSON Schema:", err);
                        continue;
                    }
                }
            }
        }
    }, [data, vc]);
    var vcSchemaName = "VerifiableCredential";
    if (vcSchema === null || vcSchema === void 0 ? void 0 : vcSchema.name) {
        vcSchemaName = vcSchema.name;
    }
    else if (Array.isArray(vc.type) && vc.type.length) {
        vcSchemaName = vc.type[vc.type.length - 1];
    }
    else if (typeof vc.type === "string") {
        vcSchemaName = vc.type;
    }
    return {
        loading: loading,
        error: error,
        vcSchema: vcSchema,
        vcSchemaName: vcSchemaName,
    };
}
exports.useVcSchema = useVcSchema;
//# sourceMappingURL=useVcSchema.js.map