"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IdentityThemeProvider = void 0;
var jsx_runtime_1 = require("react/jsx-runtime");
var styled_components_1 = require("styled-components");
var polished_1 = require("polished");
var fonts_1 = require("./fonts");
var colors_1 = require("./colors");
var blacks = colors_1.colors.blacks;
var whites = colors_1.colors.whites;
var primary = colors_1.colors.primary;
var info = colors_1.colors.info;
var success = colors_1.colors.success;
var warning = colors_1.colors.warning;
var danger = colors_1.colors.danger;
// Rimble-Identity Theme File
var identityTheme = {
    fontSizes: [12, 14, 16, 20, 24, 32, 48, 64],
    fontWeights: [0, 300, 400, 600, 700],
    letterSpacings: [0, 1, 2],
    breakpoints: ["40em", "52em", "64em"],
    lineHeights: {
        solid: 1,
        title: 1.25,
        copy: 1.5,
    },
    fonts: {
        serif: fonts_1.fonts.serif,
        sansSerif: fonts_1.fonts.sansSerif,
        mono: fonts_1.fonts.monospace,
    },
    space: [0, 4, 8, 16, 24, 32, 64, 128, 256],
    radii: [0, 4, 8, 16, 24, 32],
    sizes: [0, 4, 8, 16, 24, 32, 64, 128, 256, 512, 768, 1024, 1536],
    borders: [
        0,
        "1px solid " + colors_1.colors.moonGray,
        "1px solid " + colors_1.colors.primary.border,
        "1px solid " + colors_1.colors.primary.base,
        "1px solid " + colors_1.colors.lightGray,
    ],
    borderWidths: [0, 1, 2, 4],
    shadows: [
        "0",
        "0 2px 4px rgba(50, 50, 63, 0.1)",
        "0 8px 16px rgba(50, 50, 63, 0.1)",
        "0 7px 14px rgba(50, 50, 63, 0.1)",
        "0 2px 6px rgba(0, 0, 0, .3)",
    ],
    opacity: {
        disabled: 0.4,
    },
    colors: {
        text: colors_1.colors.nearBlack,
        background: colors_1.baseColors.white,
        primary: primary.base,
        "primary-light": primary.light[3],
        "primary-dark": primary.dark[1],
        blue: colors_1.baseColors.consensysblue,
        black: colors_1.baseColors.black,
        "near-black": colors_1.colors.nearBlack,
        "dark-gray": colors_1.colors.darkGray,
        "mid-gray": colors_1.colors.midGray,
        grey: colors_1.colors.grey,
        silver: colors_1.colors.silver,
        "light-silver": colors_1.colors.lightSilver,
        "moon-gray": colors_1.colors.moonGray,
        "light-gray": colors_1.colors.lightGray,
        "near-white": colors_1.colors.nearWhite,
        white: colors_1.baseColors.white,
        transparent: "transparent",
        blacks: [
            blacks[0],
            blacks[1],
            blacks[2],
            blacks[3],
            blacks[4],
            blacks[5],
            blacks[6],
            blacks[7],
            blacks[8],
            blacks[9],
            blacks[10],
            blacks[11],
        ],
        whites: [
            whites[0],
            whites[1],
            whites[2],
            whites[3],
            whites[4],
            whites[5],
            whites[6],
            whites[7],
            whites[8],
            whites[9],
            whites[10],
            whites[11],
        ],
        success: success.base,
        warning: warning.base,
        danger: danger.base,
        info: info.base,
    },
    zIndices: [0, 9, 99, 999, 9999],
    messageStyle: {
        base: {
            color: polished_1.shade(0.4, colors_1.colors.lightSilver),
            backgroundColor: polished_1.tint(0.9, colors_1.colors.lightSilver),
            borderColor: colors_1.colors.lightSilver,
        },
        success: {
            color: success.dark,
            backgroundColor: success.light,
            borderColor: success.base,
        },
        warning: {
            color: warning.dark,
            backgroundColor: warning.light,
            borderColor: warning.base,
        },
        danger: {
            color: danger.dark,
            backgroundColor: danger.light,
            borderColor: danger.base,
        },
        info: {
            color: info.dark,
            backgroundColor: info.light,
            borderColor: info.base,
        },
    },
    buttons: {
        primary: {
            color: primary.text,
            backgroundColor: primary.base,
            // use css custom props
            "--main-color": primary.base,
            "--contrast-color": primary.text,
        },
        warning: {
            "--main-color": "#FDF1E3",
            "--contrast-color": "#91622A",
        },
        success: {
            "--main-color": success.base,
            "--contrast-color": success.text,
        },
        danger: {
            "--main-color": danger.base,
            "--contrast-color": danger.text,
        },
    },
    buttonSizes: {
        verySmall: {
            fontSize: "0.75rem",
            fontWeight: 400,
            height: "2rem",
            minWidth: "2rem",
            padding: "0 1rem",
        },
        small: {
            fontSize: "0.875rem",
            height: "2rem",
            minWidth: "2rem",
            padding: "0 1rem",
        },
        medium: {
            fontSize: "1rem",
            height: "3rem",
            minWidth: "3rem",
        },
        large: {
            fontSize: "1.5rem",
            height: "4rem",
            minWidth: "4rem",
        },
    },
};
var IdentityThemeProvider = function (props) {
    return jsx_runtime_1.jsx(styled_components_1.ThemeProvider, __assign({ theme: __assign(__assign({}, identityTheme), props.theme) }, { children: props.children }), void 0);
};
exports.IdentityThemeProvider = IdentityThemeProvider;
//# sourceMappingURL=IdentityTheme.js.map